@@ -1,6 +1,6 @@
 package ExtUtils::Helpers::Unix;
-BEGIN {
-  $ExtUtils::Helpers::Unix::VERSION = '0.009';
+{
+  $ExtUtils::Helpers::Unix::VERSION = '0.010';
 }
 use strict;
 use warnings FATAL => 'all';
@@ -11,20 +11,13 @@ our @EXPORT = qw/make_executable split_like_shell/;
 use Text::ParseWords 3.24 qw/shellwords/;
 use ExtUtils::MakeMaker;
 
-sub _make_executable {
-  # Perl's chmod() is mapped to useful things on various non-Unix
-  # platforms, so we use it everywhere even though it looks
-  # Unixish.
-
-  foreach (@_) {
-    my $current_mode = (stat $_)[2];
-    chmod $current_mode | oct(111), $_;
-  }
-}
-
 sub make_executable {
-	ExtUtils::MM->fixin($_) for grep { -T } @_;
-	goto &_make_executable
+	my @files = @_;
+	foreach my $file (@files) {
+		my $current_mode = (stat $file)[2] + 0;
+		ExtUtils::MM->fixin($file) if -T $file;
+		chmod $current_mode | oct(111), $file;
+	}
 };
 
 sub split_like_shell {
@@ -49,7 +42,7 @@ ExtUtils::Helpers::Unix - Unix specific helper bits
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =for Pod::Coverage make_executable
 split_like_shell
